"""
User Management Package

A package for managing user-related operations using Firebase.
"""

from .clients.firebase_client import FirebaseClient, FirebaseUser
from .clients.customer_client import CustomerClient
from .clients.user_profile_client import UserProfileClient
from .clients.stripe_client import StripeClient
from .clients.product_client import ProductClient
from .clients.organization_client import OrganizationClient
from .models.product import Product
from .models.user import User
from .models.customer import Customer
from .models.subscription import Subscription
from .config import Config

__version__ = "0.4.1"

# Create a default configuration instance
config = Config.get_instance()

# Expose configuration update function at package level
def configure(**kwargs):
    """Update global configuration for user_management package.
    
    Example:
        >>> import user_management
        >>> user_management.configure(
        ...     user_table_name='custom_users',
        ...     organization_table_name='custom_orgs'
        ... )
    """
    config.update(**kwargs)

__all__ = [
    "FirebaseClient",
    "FirebaseUser",
    "CustomerClient",
    "UserProfileClient",
    "StripeClient",
    "ProductClient",
    "OrganizationClient",
    "Product",
    "User",
    "Customer",
    "Subscription",
    "config",
    "configure"
] 